==> carculator_bus-0.0.3.tar.gz: carculator_bus-0.0.3/README.md <==
# ``carculator_bus``

<p align="center">
  <img style="height:130px;" src="https://github.com/romainsacchi/coarse/raw/master/docs/mediumsmall.png">
</p>

<p align="center">
  <a href="https://badge.fury.io/py/carculator-truck" target="_blank"><img src="https://badge.fury.io/py/carculator-truck.svg"></a>
  <a href="https://travis-ci.org/romainsacchi/carculator_bus" target="_blank"><img src="https://travis-ci.org/romainsacchi/carculator_bus.svg?branch=master"></a>
  <a href="https://ci.appveyor.com/project/romainsacchi/carculator_bus" target="_blank"><img src="https://ci.appveyor.com/api/projects/status/github/romainsacchi/carculator_bus?svg=true"></a>
  <a href="https://coveralls.io/github/romainsacchi/carculator_bus" target="_blank"><img src="https://coveralls.io/repos/github/romainsacchi/carculator_bus/badge.svg"></a>
  <a href="https://carculator_bus.readthedocs.io/en/latest/" target="_blank"><img src="https://readthedocs.org/projects/carculator_bus/badge/?version=latest"></a>
 </p>

Prospective environmental and economic life cycle assessment of urban and coach buses.

A fully parameterized Python model developed by the [Technology Assessment group](https://www.psi.ch/en/ta) of the
[Paul Scherrer Institut](https://www.psi.ch/en) to perform life cycle assessments (LCA) of urban and coach buses.
Based on the Life Cycle Assessment tool for passenger vehicles [carculator](https://github.com/romainsacchi/carculator).

See [the documentation](https://carculator_bus.readthedocs.io/en/latest/index.html) for more detail, validation, etc.

The model has been the subject of a submission to the journal <i>Environmental Science and Technology</i>.
You may find a preprint version <a href="https://www.psi.ch/en/ta/preprint" target="_blank">here<a/>.


## How to install?

For the latest version, using conda::

    conda install -c romainsacchi carculator_bus
    
or for a stable release, from Pypi::

    pip install carculator_bus
    
    
No extensive documentation right now, but check out the examples notebook.

## How to use it?

See the notebook with [examples](https://github.com/romainsacchi/carculator_bus/blob/master/examples/buses.ipynb).

## Support

Do not hesitate to contact the development team at [carculator@psi.ch](mailto:carculator@psi.ch).

## Maintainers

* [Romain Sacchi](https://github.com/romainsacchi)
* [Chris Mutel](https://github.com/cmutel/)

## Contributing

See [contributing](https://github.com/romainsacchi/carculator_bus/blob/master/CONTRIBUTING.md).

## License

[BSD-3-Clause](https://github.com/romainsacchi/carculator_bus/blob/master/LICENSE). Copyright 2020 Paul Scherrer Institut.

==> carculator_bus-0.0.7.tar.gz: carculator_bus-0.0.7/README.md <==
# ``carculator_bus``

<p align="center">
  <img style="height:130px;" src="https://github.com/romainsacchi/coarse/raw/master/docs/mediumsmall.png">
</p>

<p align="center">
  <a href="https://badge.fury.io/py/carculator-truck" target="_blank"><img src="https://badge.fury.io/py/carculator-truck.svg"></a>
  <a href="https://github.com/romainsacchi/carculator_bus" target="_blank"><img src="https://github.com/romainsacchi/carculator_bus/actions/workflows/main.yml/badge.svg?branch=master"></a>
  <a href="https://ci.appveyor.com/project/romainsacchi/carculator_bus" target="_blank"><img src="https://ci.appveyor.com/api/projects/status/github/romainsacchi/carculator_bus?svg=true"></a>
  <a href="https://coveralls.io/github/romainsacchi/carculator_bus" target="_blank"><img src="https://coveralls.io/repos/github/romainsacchi/carculator_bus/badge.svg"></a>
  <a href="https://carculator_bus.readthedocs.io/en/latest/" target="_blank"><img src="https://readthedocs.org/projects/carculator_bus/badge/?version=latest"></a>
 </p>

Prospective environmental and economic life cycle assessment of urban and coach buses.

A fully parameterized Python model developed by the [Technology Assessment group](https://www.psi.ch/en/ta) of the
[Paul Scherrer Institut](https://www.psi.ch/en) to perform life cycle assessments (LCA) of urban and coach buses.
Based on the Life Cycle Assessment tool for passenger vehicles [carculator](https://github.com/romainsacchi/carculator).

See [the documentation](https://carculator_bus.readthedocs.io/en/latest/index.html) for more detail, validation, etc.

The model has been the subject of a submission to the journal <i>Environmental Science and Technology</i>.
You may find a preprint version <a href="https://www.psi.ch/en/ta/preprint" target="_blank">here<a/>.


## How to install?

For the latest version, using conda::

    conda install -c romainsacchi carculator_bus
    
or for a stable release, from Pypi::

    pip install carculator_bus
    
    
No extensive documentation right now, but check out the examples notebook.

## How to use it?

See the notebook with [examples](https://github.com/romainsacchi/carculator_bus/blob/master/examples/buses.ipynb).

## Support

Do not hesitate to contact the development team at [carculator@psi.ch](mailto:carculator@psi.ch).

## Maintainers

* [Romain Sacchi](https://github.com/romainsacchi)
* [Chris Mutel](https://github.com/cmutel/)

## Contributing

See [contributing](https://github.com/romainsacchi/carculator_bus/blob/master/CONTRIBUTING.md).

## License

[BSD-3-Clause](https://github.com/romainsacchi/carculator_bus/blob/master/LICENSE). Copyright 2020 Paul Scherrer Institut.
